from django.apps import AppConfig


class MetachoicesConfig(AppConfig):
    """Configuration for the Metachoices app."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "metachoices"
