# Generated by Django 5.2 on 2025-06-05 04:43

import metachoices.models
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Storage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('database', metachoices.models.MetaChoiceField(choices=[('DB1', 'Database 1'), ('DB2', 'Database 2'), ('DB3', 'Database 3')], help_text='Select the database for storage.', max_length=100, verbose_name='Database Storage')),
            ],
        ),
    ]
