# Generated by Django 5.2 on 2025-06-06 14:06

import metachoices.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('metachoices', '0002_storage_count'),
    ]

    operations = [
        migrations.AlterField(
            model_name='storage',
            name='count',
            field=metachoices.fields.IntegerMetaChoiceField(blank=True, choices=[(1, 'One'), (2, 'Two'), (3, 'Three')], help_text='Select a count option.', null=True, verbose_name='Count'),
        ),
    ]
