# Generated by Django 5.2 on 2025-06-05 07:01

import metachoices.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('metachoices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='storage',
            name='count',
            field=metachoices.models.MetaChoiceField(choices=[(1, 'One'), (2, 'Two'), (3, 'Three')], default=0, help_text='Select a count option.', max_length=100, verbose_name='Count'),
            preserve_default=False,
        ),
    ]
